@@ -1,4 +1,4 @@
-//$Id: treemodel_dnd.h,v 1.2 2003/01/23 22:20:33 murrayc Exp $ -*- c++ -*-
+//$Id: treemodel_dnd.h,v 1.3 2004/01/20 17:48:09 murrayc Exp $ -*- c++ -*-
 
 /* gtkmm example Copyright (C) 2002 gtkmm development team
  *
@@ -24,7 +24,7 @@
 class TreeModel_Dnd : public Gtk::TreeStore
 {
 protected:
-  explicit TreeModel_Dnd(const Gtk::TreeModelColumnRecord& columns);
+  TreeModel_Dnd();
 
 public:
 
@@ -42,7 +42,7 @@ public:
     Gtk::TreeModelColumn<bool> m_col_receivesdrags;
   };
 
-  static ModelColumns m_Columns;
+  ModelColumns m_Columns;
 
   static Glib::RefPtr<TreeModel_Dnd> create();
 
