@@ -2,7 +2,7 @@
 #ifndef _GTKMM_TARGETENTRY_H
 #define _GTKMM_TARGETENTRY_H
 
-/* $Id: targetentry.h,v 1.1.1.1 2003/01/21 13:40:59 murrayc Exp $ */
+/* $Id: targetentry.h,v 1.2 2004/02/10 17:35:11 mxpxpod Exp $ */
 
 /* targetentry.h
  *
@@ -27,6 +27,7 @@
 #include <glibmm/ustring.h>
 #include <glibmm/arrayhandle.h>
 #include <gtk/gtkselection.h> //For GtkTargetEntry.
+#include <gtkmm/enums.h>
 
 namespace Gtk
 {
@@ -35,7 +36,7 @@ class TargetEntry
 {
 public:
   TargetEntry();
-  explicit TargetEntry(const Glib::ustring& target, guint flags = 0, guint info = 0);
+  explicit TargetEntry(const Glib::ustring& target, Gtk::TargetFlags flags = Gtk::TargetFlags(0), guint info = 0);
   explicit TargetEntry(const GtkTargetEntry& gobject);
   TargetEntry(const TargetEntry& src);
   virtual ~TargetEntry();
@@ -45,8 +46,8 @@ public:
   Glib::ustring get_target() const;
   void set_target(const Glib::ustring& target);
 
-  guint get_flags() const;
-  void set_flags(guint flags);
+  Gtk::TargetFlags get_flags() const;
+  void set_flags(Gtk::TargetFlags flags);
 
   guint get_info() const;
   void set_info(guint info);
